@@ -21,14 +21,10 @@ def process_image(image: np.ndarray, direction: Direction, threshold: float, inv
 
     print(f"Processing image with {direction.name} direction, threshold={threshold}, invert={invert}, reverse_sort={reverse_sort}")
 
+    contrast: np.ndarray = create_contrast_mask(image, threshold)
     if invert:  # invert image if sorting in reverse
-        threshold = 1 - threshold
-        contrast: np.ndarray = create_contrast_mask(image, threshold)
         contrast: np.ndarray = cv2.bitwise_not(contrast)
-    else:
-        contrast: np.ndarray = create_contrast_mask(image, threshold)
     # show_image(contrast)
-
     # flip sort direction if sorting in reverse
     if reverse_sort:
         is_sort_reverse = not is_sort_reverse
@@ -45,7 +41,6 @@ def process_image(image: np.ndarray, direction: Direction, threshold: float, inv
             process_slice(row_contrast, row_image, is_sort_reverse)
 
     print("Done")
-    # show_image(image)
 
 
 def process_slice(contrast_slice: np.ndarray, image_slice: np.ndarray, is_sort_reverse: bool) -> None:
@@ -118,7 +113,8 @@ def sort_pixels(image: np.ndarray, reverse: bool = False) -> None:
         return
 
     # sort by luminance
-    luminance = np.sum(image * [0.3, 0.59, 0.11], axis=-1)
+    # numpy is b g r
+    luminance = np.sum(image * [0.11, 0.59, 0.3], axis=-1)
     index = np.argsort(luminance)
 
     if reverse:
