@@ -8,5 +8,5 @@ import pixelsort
 @pytest.mark.parametrize("test_case", test_cases)
 def test_image_mask(image, test_case: dict):
     # call process function
-    pixelsort.image.process(image, test_case["direction"], test_case["threshold"], test_case["invert"], test_case["reverse_sort"])
-    assert True
\ No newline at end of file
+    pixelsort.image.process_image(image, test_case["direction"], test_case["threshold"], test_case["invert"], test_case["reverse_sort"])
+    assert True
